California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images | Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: Prior Elections 2024 PRIMARY 2022 GENERAL 2022 PRIMARY 2022 SPECIAL ELECTION (ASSEMBLY 11) 2022 SPECIAL ELECTION (ASSEMBLY 62) 2022 SPECIAL ELECTION (ASSEMBLY 80) 2022 SPECIAL ELECTION (ASSEMBLY 17) 2022 SPECIAL ELECTION (ASSEMBLY 49) 2021 SPECIAL ELECTION (GOVERNOR) 2021 SPECIAL ELECTION (ASSEMBLY 18) 2021 SPECIAL ELECTION (ASSEMBLY 54) 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 37) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
SENATE DISTRICTS
STATE SENATE 01
DAHLE, MEGAN FENNELL, DAVID D.
| STATE SENATE 03
BOGUE, THOMAS J. CABALDON, CHRISTOPHER ELWARD, JACKIE JONES, JIMIH L. VERDER-ALIGA, ROZZANA N.
STATE SENATE 05
MC NERNEY, JERRY M. SHOEMAKER, JAMES VILLAPUDUA, CARLOS
| STATE SENATE 07
ARREGUIN, JESSE BECKLES, JOVANKA KALB, DAN E. LYBARGER, KATHRYN SOLNORDAL, JEANNE M. SWANSON, SANDRE
STATE SENATE 09
GRAYSON, TIM GRCAR, JOSEPH MINOR, DAVID RUBIO, MARISOL
| STATE SENATE 11
CORKREAN, YVETTE CRAVENS, CYNTHIA WIENER, SCOTT D. XIONG, JING CHAO
STATE SENATE 13
BECKER, JOSH GLEW, ALEXANDER LASKOWSKI, MARIA CHRISTINA
| STATE SENATE 15
CORTESE, DAVE HOWELL, ROBERT P. LOAIZA, ROY T
STATE SENATE 17
LAIRD, JOHN S. OXFORD, MICHAEL O. TAO, ERIC VIRRUETA, TONY
| STATE SENATE 19
BOGH, ROSILICIE OCHOA MIDDLETON, LISA
STATE SENATE 21
LIMON, S. MONIQUE MACK, ELIJAH
| STATE SENATE 23
GOMEZ, BLANCA A. HAMBURGER, DONALD MARTINEZ VALLADARES, SUZETTE MC CAULLEY, OLLIE M. MUELLER, KIPP
STATE SENATE 25
AHLERS, ELIZABETH W ARMENTA, SANDRA CHOI, TEDDY PEREZ, SASHA RENEE YIU, YVONNE
| STATE SENATE 27
COLLINS, SUSAN STERN, HENRY VOLOTZKY, LUCIE
STATE SENATE 29
GARCIA, CARLOS A HAZELTON, KATHLEEN TORRES O'BRIEN, JASON B. REYES, ELOISE GOMEZ
| STATE SENATE 31
CERVANTES, SABRINA FAROOQ, IMRAN ANGELOV NAVARRO, CYNTHIA
STATE SENATE 33
GONZALEZ, LENA HARDIE, SHARIFAH PAZ, MARIO
| STATE SENATE 35
CHAMBERS, MICHELLE LYONS, LAMAR MICHELIN, NILO VEGA MONTEIRO, ALEXANDRE T. RICHARDSON, LAURA ROBLES, ALBERT SPENCER, JAMES A. WILLIAMS, JENNIFER TRICHELLE-MARIE
STATE SENATE 37
ASHBAUGH, GABRIELLE S. CHOI, STEVEN CORREA, LETICIA E. CREER, JACOB N. KUO, ANTHONY LE, STEPHANIE MILES, CRYSTAL K. MOHAJER, ALEX NEWMAN, JOSH SELLECK, GUY SUAREZ, JENNY
| STATE SENATE 39
DIVINE, BOB WEBER, AKILAH
ASSEMBLY DISTRICTS
ASSEMBLY 01
AUDETTE, TENESSA HADWICK, HEATHER M. HUNT, MELISSA MEZZANO, MARK B.
| ASSEMBLY 02
CLICK, CYNTHIA ANNE GREER, MICHAEL F. HICKS, RUSTY KELLEY, ARIEL MYERS, FRANKLIN J. ROGERS, CHRIS WILLIAMS, TED
ASSEMBLY 03
DRAPER, AARON GALLAGHER, JAMES
| ASSEMBLY 04
AGUIAR-CURRY, CECILIA ELLIS, DARREN T. MC FARLAND, SHERMAN M.
ASSEMBLY 05
GAUTAM, AABHASH K. PARKER, NEVA PATTERSON, JOE SINGH, ATHENA Q.
| ASSEMBLY 06
AMANFOR, EMMANUEL ELLIS, NIKKI FRAME, SEAN HERBER, ROSANNA KRELL, MAGGY MARQUEZ, CARLOS MARTINEZ, KEVIN O. MINTON, EVAN M. ROMERO, PRESTON VILLESCAZ, PAULA
ASSEMBLY 07
CHALAMCHERLA, YK HOOVER, JOSH MIDDLETON, PORSCHE
| ASSEMBLY 08
HELSEL, CALEB MATHESON, MICHAEL A.F. RADANOVICH, GEORGE TANGIPA, DAVID
ASSEMBLY 09
FLORA, HEATH NOBRIGA, TAMI ROWLISON, ROSELLA A. SMITH, BELINDA L.
| ASSEMBLY 10
NGUYEN, STEPHANIE SINGH, VINAYA K.
ASSEMBLY 11
ENNIS, DAVID FLACK, JEFFREY D. WALLIS, WANDA WILSON, LORI
| ASSEMBLY 12
CERVANTES, ERYN M. CONNOLLY, DAMON PODSHADLEY, ANDREW
ASSEMBLY 13
AGUILAR MENDEZ, DENISE I RANSOM, RHODESIA VILLAPUDUA, EDITH
| ASSEMBLY 14
JAIN, UTKARSH SMITH, MARGOT W. WICKS, BUFFY
ASSEMBLY 15
FARIAS, ANAMARIE A. LEDO, SONIA MITCHOFF, KAREN WILSON, MONICA E.
| ASSEMBLY 16
BAUER-KAHAN, REBECCA RUBAY, JOSEPH A.
ASSEMBLY 17
DUKE, OTTO HANEY, MATT NORIS-BARRERA, MANUEL
| ASSEMBLY 18
BONTA, MIA KENNEY, CHEYENNE M. PECHENUK, MINDY SANDFORD, ANDRE
ASSEMBLY 19
FLAMENCO, NADIA LEE, DAVID E. SODHANI, ARJUN GUSTAV STEFANI, CATHERINE
| ASSEMBLY 20
ORTEGA-TORO, LIZ SHANBHOGUE, SANGEETHA
ASSEMBLY 21
GILHAM, MARK PAPAN, DIANE
| ASSEMBLY 22
ALANIS, JUAN SELF, JESSICA S.
ASSEMBLY 23
BERMAN, MARC E. KOU, LYDIA MARSON, ALLAN K. MATTAMMAL, GUS
| ASSEMBLY 24
BRUNTON, ROBERT (BOB) L. LEE, ALEX SOUZA, MARTI
ASSEMBLY 25
KALRA, ASH NGO, LAN STROLL, THEODORE J.
| ASSEMBLY 26
AHRENS, PATRICK DIN, OMAR F. GARG, ASHISH GOODWYN, ROBERT D. SONG, SOPHIE YAN SREEKRISHNAN, TARA
ASSEMBLY 27
ROSE, JOANNA LYNN GARCIA SORIA, ESMERALDA
| ASSEMBLY 28
LAWLER, LIZ PELLERIN, GAIL
ASSEMBLY 29
PAINE, JAMES W. RIVAS, ROBERT
| ASSEMBLY 30
ADDIS, DAWN J. EPPERSON, DALILA
ASSEMBLY 31
ARAMBULA, JOAQUIN VERDUZCO, SOLOMON
| ASSEMBLY 32
FONG, VINCENT K. SMITH, IAN DAVID WEIR, KEN WILLIS, THOMAS JOSEPH WOOD, DAVID DUANE
ASSEMBLY 33
AVILA, XAVIER CERROS, HIPOLITO A. MACARENO, RUBEN MACEDO, ALEXANDRA M RUIZ, ANGEL
| ASSEMBLY 34
LACKEY, THOMAS W. ORTEGA MARTINEZ JR., RICARDO
ASSEMBLY 35
BAINS, JASMEET ROSAS, ROBERT
| ASSEMBLY 36
ACUNA, JOEY FERMON, WAYMOND GARCIA, EDGARD GONZALEZ, JEFFREY MORSE, KALIN K. OLIVA, TOMAS RODRIGUEZ, ERIC L.
ASSEMBLY 37
DOMINGUES, SARI M HART, GREGG A,
| ASSEMBLY 38
BABER, DEBORAH E. BENNETT, STEPHEN A.
ASSEMBLY 39
CARRILLO, JUAN MARSH, PAUL A.
| ASSEMBLY 40
GIPSON, PATRICK LEE SCHIAVO, PILAR
ASSEMBLY 41
HARABEDIAN, JOHN LEANO, JED MARTINEZ, MICHELLE DEL ROSARIO RIDDLE, PHLUNTE
| ASSEMBLY 42
IRWIN, JACQUI V. NORDBLUM, TED K.
ASSEMBLY 43
GARCIA, VICTORIA GARCIA, WALTER HURTADO, SAUL MINASOVA, CARMENLINA NOVICK, FELICIA L. RODRIGUEZ, CELESTE
| ASSEMBLY 44
ASATRYAN, ELEN HAN, EDWARD HELLIGAR, CARMENITA I PIERSON, STEVE PRYOR, ADAM D. RODRIGUEZ, TONY SCHULTZ, NICHOLAS B.C. SUMMER, ADAM M.
ASSEMBLY 45
OLSON, SCOTT P. RAMOS, JAMES
| ASSEMBLY 46
GABRIEL, JESSE SCHROEDER, TRACEY
ASSEMBLY 47
HOLSTEGE, CHRISTY SWAIN, JAMIE L WALLIS, GREG
| ASSEMBLY 48
RUBIO, BLANCA TABATABAI, BRIAN TRAN, DAN T.
ASSEMBLY 49
FONG, MICHAEL LIU, LONG "DAVID"
| ASSEMBLY 50
GARCIA, ROBERT PEREZ, ADAM SHAW, DEJONAE STEIN, SHARON LYN
ASSEMBLY 51
BAGHERI, SHIVA G. CHAVEZ ZBUR, RICK HOHIL, STEPHAN
| ASSEMBLY 52
CALOZA, JESSICA CARRILLO, JR., FRANCISCO CORONADO, GENESIS L FANARA, ANTHONY L. GIRON, HECTOR DAVID LEON, CARLOS PITTMAN, SHANNEL QUINONES, SOFIA G. RUIZ, ARI SILLS, STEPHEN
ASSEMBLY 53
GOYTIA, CARLOS HERNANDEZ, FRANCISCO JAVIER RODRIGUEZ, MICHELLE TORRES, ROBERT WILSON, NICK
| ASSEMBLY 54
ALANIZ, ELAINE GONZALEZ, MARK YI, JOHN
ASSEMBLY 55
BRYAN, ISAAC CASCIO, KEITH G.
| ASSEMBLY 56
CALDERON, LISA MARTINEZ, JESSICA SERRANO, NATASHA
ASSEMBLY 57
AKILI, GREGORY ELHAWARY, ZEINAB SADE MARTINEZ, EFREN PERRY, TARA VASQUEZ, DULCE
| ASSEMBLY 58
CASTILLO, LETICIA CERVANTES, CLARISSA FIERRO, RONALDO
ASSEMBLY 59
CHEN, PHILLIP OBRAND, DAVE
| ASSEMBLY 60
DIAZ NAVA, HECTOR EDWARDS, RONALD R. JACKSON, COREY A.
ASSEMBLY 61
HERNANDEZ, ALFONSO MC KINNOR, TINA
| ASSEMBLY 62
ESTRADA, MARIA JONES, PAUL I. SOLACHE, JOSE
ASSEMBLY 63
ESSAYLI, BILL MUNGUIA, ORLANDO H. SHOULTS, CHRISTOPHER
| ASSEMBLY 64
ORTIZ JR., RAUL PACHECO, BLANCA
ASSEMBLY 65
GIPSON, MIKE GUTIERREZ, LYDIA A.
| ASSEMBLY 66
BARKS, GEORGE G. MURATSUCHI, AL
ASSEMBLY 67
CULVER, ELIZABETH "BETH" LEE, JACOB W.H. QUIRK-SILVA, SHARON
| ASSEMBLY 68
TARDIF, MIKE VALENCIA, AVELINO
ASSEMBLY 69
LOWENTHAL, JOSH RODRIGUEZ, JOSHUA
| ASSEMBLY 70
PHAM, JIMMY D. TA, TRI
ASSEMBLY 71
KEPHART, GARY R. KHAN, BABAR SANCHEZ, KATHRYN
| ASSEMBLY 72
DIXON, DIANE JONES, DOM
ASSEMBLY 73
ABRAHAM, HENGAMEH (HENNY) PEOTTER, SCOTT PETRIE-NORRIS, COTTIE
| ASSEMBLY 74
DAVIES, LAURIE DUNCAN, CHRIS
ASSEMBLY 75
DE MAIO, CARL DOUGHERTY, CHRISTIE MARIE FERNANDES, JACK J. FREW, JOY HAYES, ANDREW JUZA, KEVIN
| ASSEMBLY 76
BRUCE-LANE, KRISTIE PATEL, DARSHANA R ROCHA, JOSEPH
ASSEMBLY 77
BOERNER HORVATH, TASHA BROWNE IV, HERBERT J. KUPFERSTEIN, HENNY
| ASSEMBLY 78
WARD, CHRISTOPHER M.
ASSEMBLY 79
PARENT, COLIN SHARP-COLLINS, LA SHAE N VASQUEZ, RACQUEL
| ASSEMBLY 80
ALVAREZ, DAVID WILLIAMS, MICHAEL W.